@@ -62,14 +62,35 @@ G_DEFINE_TYPE_WITH_CODE (PhotosFacebookItem, photos_facebook_item, PHOTOS_TYPE_B
                                                          0));
 
 
+static gchar *
+photos_facebook_item_create_filename_fallback (PhotosBaseItem *item)
+{
+  const gchar *identifier;
+  const gchar *mime_type;
+  gchar *extension = NULL;
+  gchar *ret_val;
+
+  identifier = photos_base_item_get_identifier (item) + strlen ("facebook:");
+  mime_type = photos_base_item_get_mime_type (item);
+  extension = photos_utils_get_extension_from_mime_type (mime_type);
+  if (extension == NULL)
+    extension = g_strdup ("tmp");
+
+  ret_val = g_strdup_printf ("%s.%s", identifier, extension);
+
+  g_free (extension);
+  return ret_val;
+}
+
+
 static gchar *
 photos_facebook_item_create_name_fallback (PhotosBaseItem *item)
 {
   PhotosFacebookItem *self = PHOTOS_FACEBOOK_ITEM (item);
   GDateTime *date_modified;
   const gchar *provider_name;
-  gchar *ret_val;
   gchar *date_modified_str;
+  gchar *ret_val;
   gint64 mtime;
 
   provider_name = photos_utils_get_provider_name (self->src_mngr, item);
@@ -93,10 +114,11 @@ static GFBGraphPhoto *
 photos_facebook_get_gfbgraph_photo (PhotosBaseItem *item, GCancellable *cancellable, GError **error)
 {
   PhotosFacebookItem *self = PHOTOS_FACEBOOK_ITEM (item);
-  PhotosSource *source;
-  const gchar *identifier, *resource_urn;
   GFBGraphGoaAuthorizer *authorizer;
   GFBGraphPhoto *photo = NULL;
+  PhotosSource *source;
+  const gchar *identifier;
+  const gchar *resource_urn;
 
   resource_urn = photos_base_item_get_resource_urn (item);
   source = PHOTOS_SOURCE (photos_base_manager_get_object_by_id (self->src_mngr, resource_urn));
@@ -116,11 +138,13 @@ photos_facebook_get_gfbgraph_photo (PhotosBaseItem *item, GCancellable *cancella
 static gboolean
 photos_facebook_item_create_thumbnail (PhotosBaseItem *item, GCancellable *cancellable, GError **error)
 {
+  GFile *local_file = NULL;
+  GFile *remote_file = NULL;
   GFBGraphPhoto *photo = NULL;
   const GFBGraphPhotoImage *thumbnail_image;
-  gchar *local_path = NULL, *local_dir = NULL;
-  GFile *local_file = NULL, *remote_file = NULL;
   gboolean ret_val = FALSE;
+  gchar *local_dir = NULL;
+  gchar *local_path = NULL;
 
   photo = photos_facebook_get_gfbgraph_photo (item, cancellable, error);
   if (photo == NULL)
@@ -154,8 +178,8 @@ photos_facebook_item_create_thumbnail (PhotosBaseItem *item, GCancellable *cance
   ret_val = TRUE;
 
  out:
-  g_free (local_path);
   g_free (local_dir);
+  g_free (local_path);
   g_clear_object (&local_file);
   g_clear_object (&remote_file);
   g_clear_object (&photo);
@@ -166,16 +190,13 @@ photos_facebook_item_create_thumbnail (PhotosBaseItem *item, GCancellable *cance
 static gchar *
 photos_facebook_item_download (PhotosBaseItem *item, GCancellable *cancellable, GError **error)
 {
-  GFBGraphPhoto *photo = NULL;
-  const GFBGraphPhotoImage *higher_image;
   GFile *local_file = NULL;
   GFile *remote_file = NULL;
+  GFBGraphPhoto *photo = NULL;
+  const GFBGraphPhotoImage *higher_image;
   const gchar *cache_dir;
-  const gchar *mime_type;
-  const gchar *identifier;
-  gchar *extension = NULL;
+  const gchar *local_filename;
   gchar *local_dir = NULL;
-  gchar *local_filename = NULL;
   gchar *local_path = NULL;
   gchar *ret_val = NULL;
 
@@ -183,12 +204,7 @@ photos_facebook_item_download (PhotosBaseItem *item, GCancellable *cancellable,
   local_dir = g_build_filename (cache_dir, PACKAGE_TARNAME, "facebook", NULL);
   g_mkdir_with_parents (local_dir, 0700);
 
-  identifier = photos_base_item_get_identifier (item) + strlen ("facebook:");
-  mime_type = photos_base_item_get_mime_type (item);
-  extension = photos_utils_get_extension_from_mime_type (mime_type);
-  if (extension == NULL)
-    extension = g_strdup ("tmp");
-  local_filename = g_strdup_printf ("%s.%s", identifier, extension);
+  local_filename = photos_base_item_get_filename (item);
   local_path = g_build_filename (local_dir, local_filename, NULL);
   if (g_file_test (local_path, G_FILE_TEST_EXISTS))
     goto end;
@@ -225,10 +241,8 @@ photos_facebook_item_download (PhotosBaseItem *item, GCancellable *cancellable,
   local_path = NULL;
 
  out:
-  g_free (local_path);
-  g_free (local_filename);
   g_free (local_dir);
-  g_free (extension);
+  g_free (local_path);
   g_clear_object (&local_file);
   g_clear_object (&remote_file);
   g_clear_object (&photo);
@@ -318,6 +332,7 @@ photos_facebook_item_class_init (PhotosFacebookItemClass *class)
 
   object_class->constructed = photos_facebook_item_constructed;
   object_class->dispose = photos_facebook_item_dispose;
+  base_item_class->create_filename_fallback = photos_facebook_item_create_filename_fallback;
   base_item_class->create_name_fallback = photos_facebook_item_create_name_fallback;
   base_item_class->create_thumbnail = photos_facebook_item_create_thumbnail;
   base_item_class->download = photos_facebook_item_download;
